
##############################################################################
#
# Copyright (c) 2003-2013 by The University of Queensland
# http://www.uq.edu.au
#
# Primary Business: Queensland, Australia
# Licensed under the Apache License, version 2.0
# http://www.apache.org/licenses/LICENSE-2.0
#
# Development until 2012 by Earth Systems Science Computational Center (ESSCC)
# Development since 2012 by School of Earth Sciences
#
##############################################################################

from templates.wheezy_options import *

# mpi = 'none'
mpi = 'OPENMPI'
boost_libs = ['boost_python-py27']
umfpack = True
silo = True

